Description Usage Arguments Value Examples
This function returns the prior distributions, and can be used to check that the priors are correctly specified (e.g., when supplying custom priors).
1 | get_prior(object)
|
object |
An object of class |
model priors are printed out.
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.