Description Usage Arguments Value Note Examples
The package metafor is perhaps the gold-standard for
meta-analysis in R. This function allows for sampling
from the posterior distribution of a model originally estimated
with metafor.
1 |
object |
an object of class |
data |
data frame containing the variables in the model. |
... |
Currently ignored |
An object of class blsmeta (see blsmeta)
This function works for any kind of model fitted with rma.
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.