Description Usage Arguments Value Examples
View source: R/linear_hypothesis.R
Test Linear Hypotheses for Posterior Samples
1 2 3 4 5 6 7 8 9 | linear_hypothesis(
lin_comb,
obj,
cred = 0.95,
sub_model = NULL,
print_names = FALSE,
rope = NULL,
contrast = NULL
)
|
lin_comb |
A string specifying a linear combination of variables,
or a list of variable names if using |
obj |
An object of class |
cred |
The level for which a credible interval should be computed. |
sub_model |
character. Which sub-model for the hypotheses, with options
including |
print_names |
logical. Should the parameter names be printed ? This is useful for specifying the hypotheses, as the names need to be exact. |
rope |
Specify a ROPE. Optional. |
contrast |
A contrast matrix specifying which combinations to test. Optional. |
An object of class linear_hypothesis
1 2 3 4 5 6 7 8 9 10 11 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.